/*
 MIDI Foot Trigger
 
 * Use to fire off samples while you play bass, guitar, or other intruments
 
 The circuit:
 * digital in 1 connected to MIDI jack pin 5
 * MIDI jack pin 2 connected to ground
 * MIDI jack pin 4 connected to +5V through 220-ohm resistor
 Attach a MIDI cable to the jack, then to a MIDI synth or other input tupe to fire samples
 
 * Button assigned to pin 2 of Ardurino

 created 8 Jul 2012
 by Rob Toole

 This example code is in the public domain.
 */

// set pin numbers:
const int buttonPin = 2;     // the number of the pushbutton pin
const int ledPin =  13;      // the number of the LED pin
int buttonState = 0;         // variable for reading the pushbutton status

void setup() {
  //  Set MIDI baud rate:
  Serial.begin(31250);
  pinMode(ledPin, OUTPUT);
}

void loop() {
    
    // assign midi note
    int Cnote = 0x30;
    
    // read the state of the pushbutton value:
    buttonState = digitalRead(buttonPin);

    // check if the pushbutton is pressed.
    // if it is, the buttonState is HIGH:
    if (buttonState == HIGH) {     
      // Play midi note: Note on channel 1 (0x90), some note variable in this case (Cnote), middle velocity (0x45):
      noteOn(0x90, Cnote, 0x45);
      // turn LED on to indicate successful button press:
      digitalWrite(ledPin, HIGH);
     // delay to supress stuttering 
      delay(1000); 
    } 
    else {
      // turn LED off:
      digitalWrite(ledPin, LOW);  
    }
}

//  plays a MIDI note.  Doesn't check to see that
//  cmd is greater than 127, or that data values are less than 127:
void noteOn(int cmd, int pitch, int velocity) {
  Serial.write(cmd);
  Serial.write(pitch);
  Serial.write(velocity);
}
